@@ -135,5 +135,8 @@ PhoshShellDebugFlags phosh_shell_get_debug_flags (PhoshShell *self);
 gboolean             phosh_shell_get_show_splash (PhoshShell *self);
 gboolean             phosh_shell_get_docked      (PhoshShell *self);
 gboolean             phosh_shell_get_blanked     (PhoshShell *self);
+gboolean             phosh_shell_activate_action (PhoshShell *self,
+                                                  const char *action,
+                                                  GVariant   *parameter);
 
 G_END_DECLS
