@@ -86,11 +86,9 @@ main (int argc, char *argv[])
 
   g_test_init (&argc, &argv, NULL);
 
-  /* Preserve DISPLAY for wlroots x11 backend */
-  cfg = phosh_test_full_shell_fixture_cfg_new (g_getenv ("DISPLAY"), "phosh-screenshot-manager");
+  cfg = phosh_test_full_shell_fixture_cfg_new (NULL, "phosh-screenshot-manager");
 
-  g_test_add ("/phosh/dbus/screenshot-manager/png", PhoshTestFullShellFixture, cfg,
-              phosh_test_full_shell_setup, test_phosh_screenshot_png, phosh_test_full_shell_teardown);
+  PHOSH_FULL_SHELL_TEST_ADD ("/phosh/dbus/screenshot-manager/png", cfg, test_phosh_screenshot_png);
 
   return g_test_run ();
 }
