@@ -6,34 +6,15 @@
  * Author: Guido Günther <agx@sigxcpu.org>
  */
 
-#include "testlib.h"
+#include "testlib-compositor.h"
 
 #include "system-modal.h"
 
 #include <glib.h>
 
 
-typedef struct _Fixture {
-  PhoshTestCompositorState *state;
-} Fixture;
-
-
 static void
-compositor_setup (Fixture *fixture, gconstpointer unused)
-{
-  fixture->state = phosh_test_compositor_new (TRUE);
-  g_assert_nonnull (fixture->state);
-}
-
-static void
-compositor_teardown (Fixture *fixture, gconstpointer unused)
-{
-  phosh_test_compositor_free (fixture->state);
-}
-
-
-static void
-test_system_modal_new (Fixture *fixture, gconstpointer unused)
+test_system_modal_new (PhoshTestCompositorFixture *fixture, gconstpointer unused)
 {
   GtkWidget *modal = phosh_system_modal_new (phosh_test_get_monitor ());
 
@@ -47,7 +28,7 @@ test_system_modal_new (Fixture *fixture, gconstpointer unused)
 
 
 static void
-test_system_modal_g_object_new (Fixture *fixture, gconstpointer unused)
+test_system_modal_g_object_new (PhoshTestCompositorFixture *fixture, gconstpointer unused)
 {
   GtkWidget *modal = g_object_new (PHOSH_TYPE_SYSTEM_MODAL,
                                    "monitor", phosh_test_get_monitor (),
@@ -72,10 +53,8 @@ main (int   argc,
 {
   g_test_init (&argc, &argv, NULL);
 
-  g_test_add ("/phosh/system-modal/new", Fixture, NULL,
-              compositor_setup, test_system_modal_new, compositor_teardown);
-  g_test_add ("/phosh/system-modal/g_object_new", Fixture, NULL,
-              compositor_setup, test_system_modal_g_object_new, compositor_teardown);
+  PHOSH_COMPOSITOR_TEST_ADD ("/phosh/system-modal/new", test_system_modal_new);
+  PHOSH_COMPOSITOR_TEST_ADD ("/phosh/system-modal/g_object_new", test_system_modal_g_object_new);
 
   return g_test_run ();
 }
